@@ -558,7 +558,7 @@ impl<'de: 'c, 'c> TtlvDeserializer<'de, 'c> {
             if let Some(wanted_values) = wanted_values {
                 if let Some(seen_enum_val) = self.tag_value_store.borrow().get(&ItemTag::from_str(wanted_tag)?) {
                     for wanted_value in wanted_values.split(',') {
-                        if *seen_enum_val == wanted_value {
+                        if *seen_enum_val == wanted_value.trim() {
                             return Ok(true);
                         }
                     }
@@ -1381,4 +1381,110 @@ mod test {
             panic!("Wrong payload");
         }
     }
+
+    // ============================================================================================================
+    // 1. Setup some test data structures that will exercise the is_variant_applicable() logic
+    //    by marking some enum fields with #[serde(rename(deserialize = "if ..."))].
+    // ============================================================================================================
+    use serde_derive::Serialize;
+
+    #[derive(Deserialize, Serialize, PartialEq, Debug)]
+    #[serde(rename = "0x420042")]
+    enum KeyFormatType {
+        #[serde(rename = "0x00000001")]
+        Raw,
+
+        #[serde(rename = "0x00000002")]
+        Opaque,
+
+        #[serde(rename = "0x00000007")]
+        TransparentSymmetricKey,
+    }
+
+    // Note: Transparent is needed on serialization otherwise the unit type enum variants will cause TTLV
+    // structs to be written when the intent is that only a value is written thus we must make the newtype
+    // wrapper "transparent" so that the serializer sees through it to the inner type and ignores the outer
+    // wrapper.
+    #[derive(Deserialize, Serialize, PartialEq, Debug)]
+    #[serde(rename = "0x420043")]
+    enum KeyMaterial {
+        #[serde(rename(deserialize = "if 0x420042 in [0x00000001, 0x00000002, 0x00000003, 0x00000004, 0x00000006]"))] // Raw, Opaque, PKCS1, PKCS8 or ECPrivateKey
+        #[serde(rename(serialize = "Transparent"))]
+        Bytes(i32),
+
+        #[serde(rename(deserialize = "if 0x420042 == 0x00000007"))]
+        #[serde(rename(serialize = "Transparent"))]
+        TransparentSymmetricKey(String),
+    }
+
+    #[derive(Deserialize, Serialize, PartialEq, Debug)]
+    #[serde(rename = "0x123456")]
+    struct SomeKey {
+        key_format_type: KeyFormatType, // the value encountered when deserializing this field
+        key_material: KeyMaterial,      // determines the variant to deserialize into this field
+    }
+
+    #[test]
+    fn test_is_variant_applicable_if_equal() {
+        // ============================================================================================================
+        // 4. Verify that the if equal condition on KeyMaterial::TransparentSymmetricKey() is matched when
+        //    KeyFormatType::TransparentSymmetricKey is used.
+        // ============================================================================================================
+        let input_var = SomeKey {
+            key_format_type: KeyFormatType::TransparentSymmetricKey,
+            key_material: KeyMaterial::TransparentSymmetricKey("Blah".into()),
+        };
+
+        let expected_hex = concat!(
+            "123456 01 00000020",
+            "  420042 05 00000004 00000007 00000000", // enum variant 0x00000007
+            "  420043 07 00000004 426C6168 00000000"  // string value "Blah"
+        ).replace(" ", "");
+        let serialized_bytes = crate::ser::to_vec(&input_var).unwrap();
+        assert_eq!(expected_hex, hex::encode_upper(&serialized_bytes));
+
+        let output_var: SomeKey = crate::de::from_slice(serialized_bytes.as_slice()).unwrap();
+        assert_eq!(output_var, input_var);
+    }
+
+    #[test]
+    fn test_is_variant_applicable_if_in() {
+        // ============================================================================================================
+        // Verify that the if in condition on KeyMaterial::Bytes() is matched when KeyFormatType::Raw is used.
+        // ============================================================================================================
+        let input_var = SomeKey {
+            key_format_type: KeyFormatType::Raw,
+            key_material: KeyMaterial::Bytes(0xFF),
+        };
+
+        let expected_hex = concat!(
+            "123456 01 00000020",
+            "  420042 05 00000004 00000001 00000000", // enum variant 0x00000001
+            "  420043 02 00000004 000000FF 00000000"  // integer value 0xFF
+        ).replace(" ", "");
+        let serialized_bytes = crate::ser::to_vec(&input_var).unwrap();
+        assert_eq!(expected_hex, hex::encode_upper(&serialized_bytes));
+
+        let output_var: SomeKey = crate::de::from_slice(serialized_bytes.as_slice()).unwrap();
+        assert_eq!(output_var, input_var);
+
+        // ============================================================================================================
+        // Verify that the if in condition on KeyMaterial::Bytes() is matched when KeyFormatType::Opaque is used.
+        // ============================================================================================================
+        let input_var = SomeKey {
+            key_format_type: KeyFormatType::Opaque,
+            key_material: KeyMaterial::Bytes(0xF0),
+        };
+
+        let expected_hex = concat!(
+            "123456 01 00000020",
+            "  420042 05 00000004 00000002 00000000", // enum variant 0x00000002
+            "  420043 02 00000004 000000F0 00000000"  // integer value 0xF0
+        ).replace(" ", "");
+        let serialized_bytes = crate::ser::to_vec(&input_var).unwrap();
+        assert_eq!(expected_hex, hex::encode_upper(&serialized_bytes));
+
+        let output_var: SomeKey = crate::de::from_slice(serialized_bytes.as_slice()).unwrap();
+        assert_eq!(output_var, input_var);
+    }
 }
